@@ -50,7 +50,7 @@ file_headers_moves = ["game_id",
                       "black_pawn_count",
                       "white_queen_count",
                       "black_queen_count",
-                      "white_black_count",
+                      "white_bishop_count",
                       "black_bishop_count",
                       "white_knight_count",
                       "black_knight_count",
